@@ -1,17 +1,18 @@
 """tiny-listener
 """
 
-__version__ = "0.0.11"
+__version__ = "0.0.14"
 
-from .context import Context, Scope
+from .context import Context, EventAlreadyExist, Scope
 from .event import Event
 from .hook import Depends, Hook, HookFunc
-from .listener import ContextNotFound, Listener, RouteNotFound
+from .listener import ContextAlreadyExist, ContextNotFound, Listener, RouteNotFound
 from .routing import Params, Route, RouteError, compile_path
 from .utils import import_from_string
 
 __all__ = [
     "__version__",
+    "ContextAlreadyExist",
     "Context",
     "Scope",
     "Event",
@@ -26,4 +27,5 @@ __all__ = [
     "RouteError",
     "compile_path",
     "import_from_string",
+    "EventAlreadyExist",
 ]
