@@ -1,16 +1,6 @@
 import re
 import uuid
-from typing import (
-    Any,
-    Callable,
-    Dict,
-    List,
-    NamedTuple,
-    Optional,
-    Pattern,
-    Tuple,
-    Union,
-)
+from typing import Any, Callable, Dict, List, NamedTuple, Pattern, Tuple, Union
 
 from .hook import Hook
 
@@ -31,12 +21,12 @@ CONVERTOR_TYPES: Dict[str, Convertor] = {
     ),
 }
 
-PARAM_REGEX = re.compile("{([a-zA-Z_][a-zA-Z0-9_]*)(:[a-zA-Z_][a-zA-Z0-9_]*)?}")
+PARAM_REGEX = re.compile(r"{([a-zA-Z_]\w*)(:[a-zA-Z_]\w*)?}")
 
 Params = Dict[str, Any]
 
 
-class RouteError(BaseException):
+class RouteError(Exception):
     pass
 
 
@@ -49,7 +39,7 @@ class Route:
         self,
         path: str,
         fn: Callable,
-        opts: Optional[Dict[str, Any]] = None,
+        opts: Union[Dict[str, Any], None] = None,
         after: Union[None, str, List[str]] = None,
     ):
         self.path = path
@@ -60,7 +50,7 @@ class Route:
             after = [after]
         self.after: List[str] = after or []
 
-    def match(self, name: str) -> Optional[Params]:
+    def match(self, name: str) -> Union[Params, None]:
         match = self.path_regex.match(name)
         if match is None:
             return None
@@ -71,9 +61,7 @@ class Route:
         return params
 
     def __repr__(self) -> str:
-        return "{}(path={}, opts={})".format(
-            self.__class__.__name__, self.path, self.opts
-        )
+        return f"{self.__class__.__name__}(path={self.path}, opts={self.opts})"
 
 
 def compile_path(path: str) -> Tuple[Pattern[str], Dict[str, Convertor]]:
@@ -102,5 +90,5 @@ def compile_path(path: str) -> Tuple[Pattern[str], Dict[str, Convertor]]:
         convertors[param_name] = convertor
         idx = match.end()
 
-    path_regex += re.escape(path[idx:]) + "$"
+    path_regex += f"{re.escape(path[idx:])}$"
     return re.compile(path_regex), convertors
